@@ -1,4 +1,4 @@
-# $Id: install.py 1767 2017-11-08 13:13:33Z mwall $
+# $Id: install.py 1788 2018-12-30 16:47:23Z mwall $
 # installer for OpenWeatherMap
 # Copyright 2014 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class OWMInstaller(ExtensionInstaller):
     def __init__(self):
         super(OWMInstaller, self).__init__(
-            version="0.7",
+            version="0.8",
             name='owm',
             description='Upload weather data to OpenWeatherMap.',
             author="Matthew Wall",
@@ -19,8 +19,7 @@ class OWMInstaller(ExtensionInstaller):
             config={
                 'StdRESTful': {
                     'OpenWeatherMap': {
-                        'username': 'INSERT_USERNAME_HERE',
-                        'password': 'INSERT_PASSWORD_HERE',
-                        'station_name': 'INSERT_STATION_NAME_HERE'}}},
+                        'appid': 'INSERT_APPID_HERE',
+                        'station_id': 'INSERT_STATION_ID_HERE'}}},
             files=[('bin/user', ['bin/user/owm.py'])]
             )
